pub struct SeekPoint {
pub sample_number: u64,
pub stream_offset: u64,
pub frame_samples: u32,
}Expand description
One SEEKTABLE seek point (FLAC__StreamMetadata_SeekPoint). In a template
(before encoding) sample_number is the target sample to make seekable and the
other two fields are 0; the encoder rewrites all three for the frame that holds
each target (see Encoder).
Fields
sample_number: u64stream_offset: u64frame_samples: u32Trait Implementations
impl Copy for SeekPoint
impl Eq for SeekPoint
impl StructuralPartialEq for SeekPoint